@@ -8,7 +8,7 @@ use ibc::core::ics04_channel::channel::{ChannelEnd, State};
 use ibc::core::ics24_host::identifier::ChainId;
 use ibc::core::ics24_host::identifier::{ChannelId, ClientId, ConnectionId, PortId};
 use ibc::Height;
-use ibc_relayer::chain::handle::{ChainHandle, ProdChainHandle};
+use ibc_relayer::chain::handle::{BaseChainHandle, ChainHandle};
 use ibc_relayer::registry::Registry;
 
 use crate::conclude::Output;
@@ -68,9 +68,9 @@ fn do_run<Chain: ChainHandle>(cmd: &QueryChannelEndsCmd) -> Result<(), Box<dyn s
 
     let chain_id = cmd.chain_id.clone();
     let port_id = cmd.port_id.clone();
-    let channel_id = cmd.channel_id.clone();
+    let channel_id = cmd.channel_id;
 
-    let mut registry = <Registry<Chain>>::from_owned((*config).clone());
+    let mut registry = <Registry<Chain>>::new((*config).clone());
     let chain = registry.get_or_spawn(&chain_id)?;
 
     let chain_height = match cmd.height {
@@ -173,13 +173,11 @@ fn do_run<Chain: ChainHandle>(cmd: &QueryChannelEndsCmd) -> Result<(), Box<dyn s
 
         Output::success(res).exit();
     }
-
-    Ok(())
 }
 
 impl Runnable for QueryChannelEndsCmd {
     fn run(&self) {
-        match do_run::<ProdChainHandle>(self) {
+        match do_run::<BaseChainHandle>(self) {
             Ok(()) => {}
             Err(e) => Output::error(format!("{}", e)).exit(),
         }
