@@ -1,15 +1,12 @@
-use alloc::sync::Arc;
 use ibc_relayer::supervisor::SupervisorOptions;
 use std::error::Error;
 use std::io;
-use std::sync::RwLock;
 
 use abscissa_core::clap::Parser;
 use abscissa_core::{Command, Runnable};
 use crossbeam_channel::Sender;
 
-use ibc_relayer::chain::handle::{ChainHandle, ProdChainHandle};
-use ibc_relayer::config::reload::ConfigReload;
+use ibc_relayer::chain::handle::{CachingChainHandle, ChainHandle};
 use ibc_relayer::config::Config;
 use ibc_relayer::registry::SharedRegistry;
 use ibc_relayer::rest;
@@ -32,19 +29,15 @@ pub struct StartCmd {
 impl Runnable for StartCmd {
     fn run(&self) {
         let config = (*app_config()).clone();
-        let config = Arc::new(RwLock::new(config));
 
-        let supervisor_handle = make_supervisor::<ProdChainHandle>(config.clone(), self.full_scan)
+        let supervisor_handle = make_supervisor::<CachingChainHandle>(config, self.full_scan)
             .unwrap_or_else(|e| {
-                Output::error(format!("Hermes failed to start, last error: {}", e)).exit();
-                unreachable!()
+                Output::error(format!("Hermes failed to start, last error: {}", e)).exit()
             });
 
         match crate::config::config_path() {
-            Some(config_path) => {
-                let reload =
-                    ConfigReload::new(config_path, config, supervisor_handle.sender.clone());
-                register_signals(reload, supervisor_handle.sender.clone()).unwrap_or_else(|e| {
+            Some(_) => {
+                register_signals(supervisor_handle.sender.clone()).unwrap_or_else(|e| {
                     warn!("failed to install signal handler: {}", e);
                 });
             }
@@ -60,13 +53,13 @@ impl Runnable for StartCmd {
 }
 
 /// Register the SIGHUP and SIGUSR1 signals, and notify the supervisor.
-/// - SIGHUP: Trigger a reload of the configuration.
+/// - [DEPRECATED] SIGHUP: Trigger a reload of the configuration.
 /// - SIGUSR1: Ask the supervisor to dump its state and print it to the console.
-fn register_signals(reload: ConfigReload, tx_cmd: Sender<SupervisorCmd>) -> Result<(), io::Error> {
+fn register_signals(tx_cmd: Sender<SupervisorCmd>) -> Result<(), io::Error> {
     use signal_hook::{consts::signal::*, iterator::Signals};
 
     let sigs = vec![
-        SIGHUP,  // Reload of configuration
+        SIGHUP,  // Reload of configuration (disabled)
         SIGUSR1, // Dump state
     ];
 
@@ -75,16 +68,12 @@ fn register_signals(reload: ConfigReload, tx_cmd: Sender<SupervisorCmd>) -> Resu
     std::thread::spawn(move || {
         for signal in &mut signals {
             match signal {
-                SIGHUP => {
-                    info!("reloading configuration (triggered by SIGHUP)");
-                    match reload.reload() {
-                        Ok(true) => info!("configuration successfully reloaded"),
-                        Ok(false) => info!("configuration did not change"),
-                        Err(e) => error!("failed to reload configuration: {}", e),
-                    }
-                }
+                SIGHUP => warn!(
+                    "configuration reloading via SIGHUP has been disabled, \
+                     the signal handler will be removed in the future"
+                ),
                 SIGUSR1 => {
-                    info!("Dumping state (triggered by SIGUSR1)");
+                    info!("dumping state (triggered by SIGUSR1)");
 
                     let (tx, rx) = crossbeam_channel::bounded(1);
                     tx_cmd.try_send(SupervisorCmd::DumpState(tx)).unwrap();
@@ -114,8 +103,8 @@ fn register_signals(reload: ConfigReload, tx_cmd: Sender<SupervisorCmd>) -> Resu
 }
 
 #[cfg(feature = "rest-server")]
-fn spawn_rest_server(config: &Arc<RwLock<Config>>) -> Option<rest::Receiver> {
-    let rest = config.read().expect("poisoned lock").rest.clone();
+fn spawn_rest_server(config: &Config) -> Option<rest::Receiver> {
+    let rest = config.rest.clone();
 
     if rest.enabled {
         let rest_config = ibc_relayer_rest::Config::new(rest.host, rest.port);
@@ -128,8 +117,8 @@ fn spawn_rest_server(config: &Arc<RwLock<Config>>) -> Option<rest::Receiver> {
 }
 
 #[cfg(not(feature = "rest-server"))]
-fn spawn_rest_server(config: &Arc<RwLock<Config>>) -> Option<rest::Receiver> {
-    let rest = config.read().expect("poisoned lock").rest.clone();
+fn spawn_rest_server(config: &Config) -> Option<rest::Receiver> {
+    let rest = config.rest.clone();
 
     if rest.enabled {
         warn!(
@@ -144,12 +133,10 @@ fn spawn_rest_server(config: &Arc<RwLock<Config>>) -> Option<rest::Receiver> {
 }
 
 #[cfg(feature = "telemetry")]
-fn spawn_telemetry_server(
-    config: &Arc<RwLock<Config>>,
-) -> Result<(), Box<dyn Error + Send + Sync>> {
+fn spawn_telemetry_server(config: &Config) -> Result<(), Box<dyn Error + Send + Sync>> {
     let state = ibc_telemetry::global();
 
-    let telemetry = config.read().expect("poisoned lock").telemetry.clone();
+    let telemetry = config.telemetry.clone();
     if telemetry.enabled {
         match ibc_telemetry::spawn((telemetry.host, telemetry.port), state.clone()) {
             Ok((addr, _)) => {
@@ -183,7 +170,7 @@ fn spawn_telemetry_server(
 }
 
 fn make_supervisor<Chain: ChainHandle>(
-    config: Arc<RwLock<Config>>,
+    config: Config,
     force_full_scan: bool,
 ) -> Result<SupervisorHandle, Box<dyn Error + Send + Sync>> {
     let registry = SharedRegistry::<Chain>::new(config.clone());
