@@ -21,7 +21,7 @@ macro_rules! tx_chan_cmd {
         let chains = match ChainHandlePair::spawn(&config, &$self.src_chain_id, &$self.dst_chain_id)
         {
             Ok(chains) => chains,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         // Retrieve the connection
@@ -30,7 +30,7 @@ macro_rules! tx_chan_cmd {
             .query_connection(&$self.dst_conn_id, Height::default())
         {
             Ok(connection) => connection,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let channel = $chan(chains, dst_connection);
@@ -78,7 +78,7 @@ impl Runnable for TxRawChanOpenInitCmd {
 
         let chains = match ChainHandlePair::spawn(&config, &self.src_chain_id, &self.dst_chain_id) {
             Ok(chains) => chains,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         // Retrieve the connection
@@ -87,7 +87,7 @@ impl Runnable for TxRawChanOpenInitCmd {
             .query_connection(&self.dst_conn_id, Height::default())
         {
             Ok(connection) => connection,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let channel = Channel {
@@ -174,7 +174,7 @@ impl Runnable for TxRawChanOpenTryCmd {
                         ClientId::default(),
                         ConnectionId::default(),
                         self.src_port_id.clone(),
-                        Some(self.src_chan_id.clone()),
+                        Some(self.src_chan_id),
                         None,
                     ),
                     b_side: ChannelSide::new(
@@ -182,7 +182,7 @@ impl Runnable for TxRawChanOpenTryCmd {
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
-                        self.dst_chan_id.clone(),
+                        self.dst_chan_id,
                         None,
                     ),
                 }
@@ -242,7 +242,7 @@ impl Runnable for TxRawChanOpenAckCmd {
                         ClientId::default(),
                         ConnectionId::default(),
                         self.src_port_id.clone(),
-                        Some(self.src_chan_id.clone()),
+                        Some(self.src_chan_id),
                         None,
                     ),
                     b_side: ChannelSide::new(
@@ -250,7 +250,7 @@ impl Runnable for TxRawChanOpenAckCmd {
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
-                        Some(self.dst_chan_id.clone()),
+                        Some(self.dst_chan_id),
                         None,
                     ),
                 }
@@ -310,7 +310,7 @@ impl Runnable for TxRawChanOpenConfirmCmd {
                         ClientId::default(),
                         ConnectionId::default(),
                         self.src_port_id.clone(),
-                        Some(self.src_chan_id.clone()),
+                        Some(self.src_chan_id),
                         None,
                     ),
                     b_side: ChannelSide::new(
@@ -318,7 +318,7 @@ impl Runnable for TxRawChanOpenConfirmCmd {
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
-                        Some(self.dst_chan_id.clone()),
+                        Some(self.dst_chan_id),
                         None,
                     ),
                 }
@@ -378,7 +378,7 @@ impl Runnable for TxRawChanCloseInitCmd {
                         ClientId::default(),
                         ConnectionId::default(),
                         self.src_port_id.clone(),
-                        Some(self.src_chan_id.clone()),
+                        Some(self.src_chan_id),
                         None,
                     ),
                     b_side: ChannelSide::new(
@@ -386,7 +386,7 @@ impl Runnable for TxRawChanCloseInitCmd {
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
-                        Some(self.dst_chan_id.clone()),
+                        Some(self.dst_chan_id),
                         None,
                     ),
                 }
@@ -446,7 +446,7 @@ impl Runnable for TxRawChanCloseConfirmCmd {
                         ClientId::default(),
                         ConnectionId::default(),
                         self.src_port_id.clone(),
-                        Some(self.src_chan_id.clone()),
+                        Some(self.src_chan_id),
                         None,
                     ),
                     b_side: ChannelSide::new(
@@ -454,7 +454,7 @@ impl Runnable for TxRawChanCloseConfirmCmd {
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
-                        Some(self.dst_chan_id.clone()),
+                        Some(self.dst_chan_id),
                         None,
                     ),
                 }
