@@ -9,7 +9,7 @@ use ibc::events::IbcEvent;
 use ibc_proto::ibc::core::client::v1::QueryClientStatesRequest;
 use ibc_relayer::chain::handle::ChainHandle;
 use ibc_relayer::config::Config;
-use ibc_relayer::foreign_client::{CreateParams, ForeignClient};
+use ibc_relayer::foreign_client::{CreateOptions, ForeignClient};
 use tendermint_light_client_verifier::types::TrustThreshold;
 
 use crate::application::app_config;
@@ -25,12 +25,15 @@ pub struct TxCreateClientCmd {
     #[clap(required = true, help = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    /// Override the default clock drift specified in the configuration.
+    /// The maximum allowed clock drift for this client.
     ///
-    /// The clock drift is a correction parameter dealing with only approximately synchronized clocks.
-    /// The local clock should always be ahead of timestamps from the blockchain; this
-    /// is the maximum amount that the local clock may drift behind a timestamp from the
-    /// blockchain.
+    /// The clock drift is a correction parameter. It helps deal with clocks
+    /// that are only approximately synchronized between the source and destination chains
+    /// of this client.
+    /// The destination chain for this client uses the clock drift parameter when deciding
+    /// to accept or reject a new header (originating from the source chain) for this client.
+    /// If this option is not specified, a suitable clock drift value is derived from the chain
+    /// configurations.
     #[clap(short = 'd', long)]
     clock_drift: Option<humantime::Duration>,
 
@@ -38,7 +41,6 @@ pub struct TxCreateClientCmd {
     ///
     /// The trusting period specifies how long a validator set is trusted for
     /// (must be shorter than the chain's unbonding period).
-
     #[clap(short = 'p', long)]
     trusting_period: Option<humantime::Duration>,
 
@@ -62,20 +64,20 @@ impl Runnable for TxCreateClientCmd {
 
         let chains = match ChainHandlePair::spawn(&config, &self.src_chain_id, &self.dst_chain_id) {
             Ok(chains) => chains,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let client = ForeignClient::restore(ClientId::default(), chains.dst, chains.src);
 
-        let params = CreateParams {
-            clock_drift: self.clock_drift.map(Into::into),
+        let options = CreateOptions {
+            max_clock_drift: self.clock_drift.map(Into::into),
             trusting_period: self.trusting_period.map(Into::into),
-            trust_threshold: self.trust_threshold,
+            trust_threshold: self.trust_threshold.map(Into::into),
         };
 
         // Trigger client creation via the "build" interface, so that we obtain the resulting event
         let res: Result<IbcEvent, Error> = client
-            .build_create_client_and_send(&params)
+            .build_create_client_and_send(options)
             .map_err(Error::foreign_client);
 
         match res {
@@ -109,14 +111,14 @@ impl Runnable for TxUpdateClientCmd {
 
         let dst_chain = match spawn_chain_runtime(&config, &self.dst_chain_id) {
             Ok(handle) => handle,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let src_chain_id =
             match dst_chain.query_client_state(&self.dst_client_id, ibc::Height::zero()) {
                 Ok(cs) => cs.chain_id(),
                 Err(e) => {
-                    return Output::error(format!(
+                    Output::error(format!(
                         "Query of client '{}' on chain '{}' failed with error: {}",
                         self.dst_client_id, self.dst_chain_id, e
                     ))
@@ -126,7 +128,7 @@ impl Runnable for TxUpdateClientCmd {
 
         let src_chain = match spawn_chain_runtime(&config, &src_chain_id) {
             Ok(handle) => handle,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let height = match self.target_height {
@@ -171,14 +173,14 @@ impl Runnable for TxUpgradeClientCmd {
 
         let dst_chain = match spawn_chain_runtime(&config, &self.chain_id) {
             Ok(handle) => handle,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let src_chain_id = match dst_chain.query_client_state(&self.client_id, ibc::Height::zero())
         {
             Ok(cs) => cs.chain_id(),
             Err(e) => {
-                return Output::error(format!(
+                Output::error(format!(
                     "Query of client '{}' on chain '{}' failed with error: {}",
                     self.client_id, self.chain_id, e
                 ))
@@ -188,7 +190,7 @@ impl Runnable for TxUpgradeClientCmd {
 
         let src_chain = match spawn_chain_runtime(&config, &src_chain_id) {
             Ok(handle) => handle,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let client = ForeignClient::find(src_chain, dst_chain, &self.client_id)
@@ -217,7 +219,7 @@ impl Runnable for TxUpgradeClientsCmd {
         let config = app_config();
         let src_chain = match spawn_chain_runtime(&config, &self.src_chain_id) {
             Ok(handle) => handle,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let results = config
