@@ -1,6 +1,7 @@
 use abscissa_core::clap::Parser;
 use abscissa_core::{config::Override, Command, FrameworkErrorKind, Runnable};
 
+use core::time::Duration;
 use ibc::{
     core::{
         ics02_client::client_state::ClientState,
@@ -136,12 +137,12 @@ impl TxIcs20MsgTransferCmd {
 
         let opts = TransferOptions {
             packet_src_port_id: self.src_port_id.clone(),
-            packet_src_channel_id: self.src_channel_id.clone(),
+            packet_src_channel_id: self.src_channel_id,
             amount: self.amount,
             denom,
             receiver: self.receiver.clone(),
             timeout_height_offset: self.timeout_height_offset,
-            timeout_seconds: core::time::Duration::from_secs(self.timeout_seconds),
+            timeout_duration: Duration::from_secs(self.timeout_seconds),
             number_msgs,
         };
 
@@ -154,7 +155,7 @@ impl Runnable for TxIcs20MsgTransferCmd {
         let config = app_config();
 
         let opts = match self.validate_options(&config) {
-            Err(err) => return Output::error(err).exit(),
+            Err(err) => Output::error(err).exit(),
             Ok(result) => result,
         };
 
@@ -176,7 +177,7 @@ impl Runnable for TxIcs20MsgTransferCmd {
             )
             .unwrap_or_else(exit_with_unrecoverable_error);
         if !channel_end_src.is_open() {
-            return Output::error(format!(
+            Output::error(format!(
                 "the requested port/channel ('{}'/'{}') on chain id '{}' is in state '{}'; expected 'open' state",
                 opts.packet_src_port_id,
                 opts.packet_src_channel_id,
@@ -188,7 +189,7 @@ impl Runnable for TxIcs20MsgTransferCmd {
 
         let conn_id = match channel_end_src.connection_hops.first() {
             None => {
-                return Output::error(format!(
+                Output::error(format!(
                     "could not retrieve the connection hop underlying port/channel '{}'/'{}' on chain '{}'",
                     opts.packet_src_port_id, opts.packet_src_channel_id, self.src_chain_id
                 ))
@@ -215,7 +216,7 @@ impl Runnable for TxIcs20MsgTransferCmd {
         );
 
         if src_chain_client_state.chain_id() != self.dst_chain_id {
-            return Output::error(
+            Output::error(
                 format!("the requested port/channel ('{}'/'{}') provides a path from chain '{}' to \
                  chain '{}' (not to the destination chain '{}'). Bailing due to mismatching arguments.",
                         opts.packet_src_port_id, opts.packet_src_channel_id,
@@ -226,7 +227,7 @@ impl Runnable for TxIcs20MsgTransferCmd {
         // Checks pass, build and send the tx
         let res: Result<Vec<IbcEvent>, Error> =
             build_and_send_transfer_messages(&chains.src, &chains.dst, &opts)
-                .map_err(Error::packet);
+                .map_err(Error::transfer);
 
         match res {
             Ok(ev) => Output::success(ev).exit(),
