@@ -6,7 +6,6 @@ use abscissa_core::{Command, Runnable};
 use tokio::runtime::Runtime as TokioRuntime;
 
 use ibc::core::ics24_host::identifier::{ChainId, ClientId};
-use ibc::events::IbcEvent;
 use ibc_relayer::upgrade_chain::{build_and_send_ibc_upgrade_proposal, UpgradePlanOptions};
 use ibc_relayer::{
     chain::{ChainEndpoint, CosmosSdkChain},
@@ -123,7 +122,7 @@ impl Runnable for TxIbcUpgradeChainCmd {
         let config = app_config();
 
         let opts = match self.validate_options(&config) {
-            Err(err) => return Output::error(err).exit(),
+            Err(err) => Output::error(err).exit(),
             Ok(result) => result,
         };
         info!("Message {:?}", opts);
@@ -134,19 +133,18 @@ impl Runnable for TxIbcUpgradeChainCmd {
             .map_err(Error::relayer);
         let src_chain = match src_chain_res {
             Ok(chain) => chain,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
         let dst_chain_res =
             CosmosSdkChain::bootstrap(opts.dst_chain_config.clone(), rt).map_err(Error::relayer);
         let dst_chain = match dst_chain_res {
             Ok(chain) => chain,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
         };
 
-        let res: Result<Vec<IbcEvent>, Error> =
-            build_and_send_ibc_upgrade_proposal(dst_chain, src_chain, &opts)
-                .map_err(Error::upgrade_chain);
+        let res = build_and_send_ibc_upgrade_proposal(dst_chain, src_chain, &opts)
+            .map_err(Error::upgrade_chain);
 
         match res {
             Ok(ev) => Output::success(ev).exit(),
