@@ -65,7 +65,7 @@ use crate::prelude::app_reader;
 /// Functional-style method to exit a program.
 ///
 /// ## Note: See `Output::exit()` for the preferred method of exiting a relayer command.
-pub fn exit_with(out: Output) {
+pub fn exit_with(out: Output) -> ! {
     let status = out.status;
 
     // Handle the output message
@@ -99,7 +99,7 @@ pub fn json() -> bool {
 /// let res = ForeignClient::new(chains.src.clone(), chains.dst.clone());
 /// let client = match res {
 ///     Ok(client) => client,
-///     Err(e) => return Output::error(format!("{}", e)).exit(),
+///     Err(e) => Output::error(format!("{}", e)).exit(),
 /// };
 /// ```
 /// - With support from `exit_with_unrecoverable_error`:
@@ -108,10 +108,7 @@ pub fn json() -> bool {
 ///     .unwrap_or_else(exit_with_unrecoverable_error);
 /// ```
 pub fn exit_with_unrecoverable_error<T, E: fmt::Display>(err: E) -> T {
-    // TODO(@romac): Once never (!) stabilizes, adapt `Output::exit` to return !
-    //  https://github.com/informalsystems/ibc-rs/pull/688#discussion_r583758439
-    Output::error(format!("{}", err)).exit();
-    unreachable!()
+    Output::error(format!("{}", err)).exit()
 }
 
 /// The result to display before quitting, can either be a JSON value, some plain text,
@@ -208,7 +205,7 @@ impl Output {
     }
 
     /// Exits from the process with the current output. Convenience wrapper over `exit_with`.
-    pub fn exit(self) {
+    pub fn exit(self) -> ! {
         exit_with(self);
     }
 
