@@ -33,7 +33,7 @@ impl Runnable for EntryPoint {
         match &self.command {
             Some(cmd) => cmd.run(),
             None => {
-                EntryPoint::into_app().print_help().unwrap();
+                EntryPoint::command().print_help().unwrap();
                 process::exit(0);
             }
         }
@@ -43,9 +43,13 @@ impl Runnable for EntryPoint {
 impl Configurable<Config> for EntryPoint {
     /// Path to the command's configuration file
     fn config_path(&self) -> Option<PathBuf> {
-        // Skip config processing for the legacy `version` subcommand
-        if matches!(&self.command, Some(CliCmd::Version(_))) {
-            return None;
+        // Skip config processing for `completions`
+        // and the legacy `version` subcommand.
+        match &self.command {
+            Some(CliCmd::Completions(_)) | Some(CliCmd::Version(_)) => {
+                return None;
+            }
+            _ => {}
         }
 
         match &self.config {
