@@ -23,6 +23,7 @@
 extern crate alloc;
 
 pub mod application;
+pub mod cli_utils;
 pub mod commands;
 pub mod components;
 pub mod config;
@@ -30,7 +31,6 @@ pub mod prelude;
 
 pub mod error;
 
-pub(crate) mod cli_utils;
 pub(crate) mod conclude;
 pub(crate) mod entry;
 
