@@ -6,4 +6,4 @@
 pub use abscissa_core::prelude::*;
 
 /// Application state accessors
-pub use crate::application::{app_config, app_reader, app_writer};
+pub use crate::application::{app_config, app_reader};
